==> glfw-2.4.2.tar.gz: glfw-2.4.2/lib/win32/win32_dllmain.c <==
//========================================================================
// GLFW - An OpenGL framework
// File:        win32_dllmain.c
// Platform:    Windows
// API version: 2.4
// Author:      Marcus Geelnard (marcus.geelnard at home.se)
// WWW:         http://glfw.sourceforge.net
//------------------------------------------------------------------------
// Copyright (c) 2002-2004 Marcus Geelnard
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source
//    distribution.
//
// Marcus Geelnard
// marcus.geelnard at home.se
//------------------------------------------------------------------------
// $Id: win32_dllmain.c,v 1.4 2004/02/14 20:59:29 marcus256 Exp $
//========================================================================

#include "internal.h"


#if defined(GLFW_BUILD_DLL)

//========================================================================
// DllMain()
//========================================================================

int WINAPI DllMain( HINSTANCE hinst, unsigned long reason, void *x )
{
    // NOTE: Some compilers complains about hinst and x never being used -
    // never mind that (we don't want to use them)!

    switch( reason )
    {
    case DLL_PROCESS_ATTACH:
        // Initializations
        //glfwInit();   // We don't want to do that now!
        break;
    case DLL_PROCESS_DETACH:
        // Do some cleanup
        glfwTerminate();
        break;
    };

    return 1;
}

#endif // GLFW_BUILD_DLL

==> glfw_2.7.2.orig.tar.gz: glfw-2.7.2/lib/win32/win32_dllmain.c <==
//========================================================================
// GLFW - An OpenGL framework
// Platform:    Win32/WGL
// API version: 2.7
// WWW:         http://www.glfw.org/
//------------------------------------------------------------------------
// Copyright (c) 2002-2006 Marcus Geelnard
// Copyright (c) 2006-2010 Camilla Berglund <elmindreda@elmindreda.org>
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source
//    distribution.
//
//========================================================================

#include "internal.h"


#if defined(GLFW_BUILD_DLL)

//========================================================================
// GLFW DLL entry point
//========================================================================

BOOL WINAPI DllMain( HINSTANCE instance, DWORD reason, LPVOID reserved )
{
    // NOTE: Some compilers complains about instance and x never being used -
    // never mind that (we don't want to use them)!

    return TRUE;
}

#endif // GLFW_BUILD_DLL
